<?php

global $status_list;
$status_list = array (

'1'	=>	'Unbestätigt',
'2'	=>	'Neu',
'3'	=>	'Zugeteilt',
'4'	=>	'Analysieren',
'5'	=>	'Auf Kunden warten',
'6'	=>	'Benötigt Testen',
'7'	=>	'Wiedereröffnet',

);
?>
